==> pulin-vue3-common-0.0.1.tgz: package/es/components/MyLogin/index.js <==
import { resolveComponent as _resolveComponent, createVNode as _createVNode, createTextVNode as _createTextVNode } from "vue";
import { defineComponent, reactive } from 'vue';
import { useForm } from '@ant-design-vue/use';
import './login.less';
export var MyLogin = defineComponent({
  setup: function setup() {
    var form = {
      models: reactive({
        username: '',
        password: ''
      }),
      rules: reactive({
        username: [{
          required: true,
          min: 4,
          max: 15,
          type: 'string',
          message: '请输入账户名！'
        }],
        password: [{
          required: true,
          min: 4,
          max: 15,
          type: 'string',
          message: '请输入密码！'
        }]
      }),
      onSubmit: function onSubmit(e) {
        e.preventDefault(); // validate().then(() => {});
      }
    };

    var _useForm = useForm(form.models, form.rules),
        validateInfos = _useForm.validateInfos;

    return function () {
      return _createVNode("div", {
        "class": "loginBody"
      }, [_createVNode("div", {
        "class": "loginContent"
      }, [_createVNode("div", {
        "class": "loginForm"
      }, [_createVNode("div", {
        "class": "title"
      }, [_createTextVNode("\u7BA1\u7406\u5458\u767B\u9646")]), _createVNode("div", null, [_createVNode(_resolveComponent("a-form"), {
        "wrapperCol": {
          span: 24
        }
      }, {
        "default": function _default() {
          return [_createVNode(_resolveComponent("a-form-item"), validateInfos['username'], {
            "default": function _default() {
              return [_createVNode(_resolveComponent("a-input"), {
                "placeholder": "用户名",
                'value': form.models.username,
                "onUpdate:value": function onUpdateValue($event) {
                  return form.models.username = $event;
                },
                "size": "large",
                "addonBefore": function addonBefore() {
                  return _createVNode("div", {
                    "style": "height:21px;"
                  }, [_createVNode(_resolveComponent("my-icon"), {
                    "icon": "user",
                    "size": 19,
                    "color": "gray"
                  }, null)]);
                }
              }, null)];
            }
          }), _createVNode(_resolveComponent("a-form-item"), validateInfos['password'], {
            "default": function _default() {
              return [_createVNode(_resolveComponent("a-input"), {
                "type": "password",
                "size": "large",
                "placeholder": "密码",
                'value': form.models.password,
                "onUpdate:value": function onUpdateValue($event) {
                  return form.models.password = $event;
                },
                "addonBefore": function addonBefore() {
                  return _createVNode("div", {
                    "style": "height:21px;"
                  }, [_createVNode(_resolveComponent("my-icon"), {
                    "icon": "lock",
                    "size": 19,
                    "color": "gray"
                  }, null)]);
                }
              }, null)];
            }
          }), _createVNode(_resolveComponent("a-form-item"), null, {
            "default": function _default() {
              return [_createVNode(_resolveComponent("a-button"), {
                "type": "primary",
                "size": "large",
                "style": "width:100%",
                "html-type": "submit",
                "onClick": form.onSubmit
              }, {
                "default": function _default() {
                  return [_createTextVNode("\u767B\u5F55")];
                }
              })];
            }
          })];
        }
      })])])])]);
    };
  }
});

==> pulin-vue3-common-0.0.2.tgz: package/es/components/MyLogin/index.js <==
import { resolveComponent as _resolveComponent, createVNode as _createVNode, createTextVNode as _createTextVNode } from "vue";
import { defineComponent, reactive } from 'vue';
import { useForm } from '@ant-design-vue/use';
import './login.less';
export var MyLogin = defineComponent({
  props: {
    loading: {
      type: Boolean,
      "default": false
    }
  },
  setup: function setup(props, _ref) {
    var emit = _ref.emit;
    var form = {
      models: reactive({
        username: undefined,
        password: undefined
      }),
      rules: reactive({
        username: [{
          required: true,
          min: 3,
          max: 15,
          trigger: 'change',
          type: 'string',
          message: '请输入账户名！3-15位！'
        }],
        password: [{
          required: true,
          min: 6,
          trigger: 'change',
          type: 'string',
          message: '请输入密码！最低6位数！'
        }]
      })
    };

    var _useForm = useForm(form.models, form.rules),
        validate = _useForm.validate,
        validateInfos = _useForm.validateInfos;

    var onSubmit = function onSubmit(e) {
      e.preventDefault();
      validate().then(function () {
        emit('change', form.models);
      });
    };

    return function () {
      return _createVNode("div", {
        "class": "loginBody"
      }, [_createVNode("div", {
        "class": "loginContent"
      }, [_createVNode("div", {
        "class": "loginForm"
      }, [_createVNode("div", {
        "class": "title"
      }, [_createTextVNode("\u7BA1\u7406\u5458\u767B\u9646")]), _createVNode("div", null, [_createVNode(_resolveComponent("a-form"), {
        "wrapperCol": {
          span: 24
        }
      }, {
        "default": function _default() {
          return [_createVNode(_resolveComponent("a-form-item"), validateInfos['username'], {
            "default": function _default() {
              return [_createVNode(_resolveComponent("a-input"), {
                "placeholder": "用户名",
                'value': form.models.username,
                "onUpdate:value": function onUpdateValue($event) {
                  return form.models.username = $event;
                },
                "size": "large",
                "addonBefore": function addonBefore() {
                  return _createVNode("div", {
                    "style": "height:21px;"
                  }, [_createVNode(_resolveComponent("my-icon"), {
                    "icon": "user",
                    "size": 19,
                    "color": "gray"
                  }, null)]);
                }
              }, null)];
            }
          }), _createVNode(_resolveComponent("a-form-item"), validateInfos['password'], {
            "default": function _default() {
              return [_createVNode(_resolveComponent("a-input"), {
                "type": "password",
                "size": "large",
                "placeholder": "密码",
                'value': form.models.password,
                "onUpdate:value": function onUpdateValue($event) {
                  return form.models.password = $event;
                },
                "addonBefore": function addonBefore() {
                  return _createVNode("div", {
                    "style": "height:21px;"
                  }, [_createVNode(_resolveComponent("my-icon"), {
                    "icon": "lock",
                    "size": 19,
                    "color": "gray"
                  }, null)]);
                }
              }, null)];
            }
          }), _createVNode(_resolveComponent("a-form-item"), null, {
            "default": function _default() {
              return [_createVNode(_resolveComponent("a-button"), {
                "type": "primary",
                "size": "large",
                "style": "width:100%",
                "html-type": "submit",
                "loading": props.loading,
                "onClick": onSubmit
              }, {
                "default": function _default() {
                  return [_createTextVNode("\u767B\u5F55")];
                }
              })];
            }
          })];
        }
      })])])])]);
    };
  }
});
